var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import fs from 'node:fs';
const DEFAULT_FILTER = /.(jsx|tsx)/;
const JSXIMPORT_SOURCE_PRAGMA_PATTERN = /\/\*\* @jsxImportSource (?<importSource>[\w@/]+) \*\//;
const containsJsxImportSourcePragma = (contents) => {
    const match = JSXIMPORT_SOURCE_PRAGMA_PATTERN.exec(contents);
    if (!match || !match.groups)
        return null;
    return {
        pragmaStart: match.index,
        pragmaEnd: match.index + match[0].length,
        importFrom: match.groups.importSource
    };
};
const generateJsxPragmaFor = (importFrom) => `/** @jsx jsx */
import { jsx } from '${importFrom}'`;
const convertPragma = (input, { pragmaStart, pragmaEnd, importFrom }) => {
    return (input.slice(0, pragmaStart) +
        generateJsxPragmaFor(importFrom) +
        input.slice(pragmaEnd));
};
const getLoaderFromPath = (path) => path.includes('.ts') ? 'tsx' : 'jsx';
const createPlugin = ({ filter = DEFAULT_FILTER } = { filter: DEFAULT_FILTER }) => ({
    name: 'jsximportsource',
    setup: (build) => {
        build.onLoad({ filter }, ({ path }) => __awaiter(void 0, void 0, void 0, function* () {
            const input = String(yield fs.promises.readFile(path));
            const jsxImportSourceResult = containsJsxImportSourcePragma(input);
            const output = jsxImportSourceResult
                ? convertPragma(input, jsxImportSourceResult)
                : input;
            return {
                contents: output,
                loader: getLoaderFromPath(path)
            };
        }));
    }
});
export { createPlugin as jsxImportSourcePlugin };
